summaryrefslogtreecommitdiffstats
path: root/Doc/includes/typestruct.h
diff options
context:
space:
mode:
Diffstat (limited to 'Doc/includes/typestruct.h')
-rw-r--r--Doc/includes/typestruct.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/Doc/includes/typestruct.h b/Doc/includes/typestruct.h
index 7265009..9f47899 100644
--- a/Doc/includes/typestruct.h
+++ b/Doc/includes/typestruct.h
@@ -9,7 +9,8 @@ typedef struct _typeobject {
printfunc tp_print;
getattrfunc tp_getattr;
setattrfunc tp_setattr;
- void *tp_reserved; /* formerly known as tp_compare */
+ PyAsyncMethods *tp_as_async; /* formerly known as tp_compare (Python 2)
+ or tp_reserved (Python 3) */
reprfunc tp_repr;
/* Method suites for standard classes */